@@ -154,6 +154,10 @@ class Settings(object):
         self.on_scenario_started = self.get_setting(settings, "on_scenario_started", None)
         self.on_scenario_completed = self.get_setting(settings, "on_scenario_completed", None)
 
+        self.on_before_action = self.get_setting(settings, 'on_before_action', None)
+        self.on_action_successful = self.get_setting(settings, 'on_action_successful', None)
+        self.on_action_error = self.get_setting(settings, 'on_action_error', None)
+
     def get_setting(self, settings, key, default):
         value = settings.get(key, None)
 
